@@ -5,14 +5,11 @@ test_that("changePixelColor", {
   mat <- matrix(0, 4, 4)
   mat[2:3, 2:3] <- 1
   img <- as.cimg(mat)
-  coordinates <- data.frame(
-    x = c(1, 3),
-    y = c(1, 3)
-  )
+  coordinates <- data.frame(x = c(1, 3),
+                            y = c(1, 3))
 
   expect_error(changePixelColor(mat, coordinates),
-    regexp = "image must be of class 'cimg'"
-  )
+               regexp = "image must be of class 'cimg'")
   expect_no_error(changePixelColor(img, coordinates))
 
   expect_equal(dim(img)[4], 1)
@@ -25,7 +22,7 @@ test_that("changePixelColor", {
   expect_equal(img[1], as.array(img)[1])
 
   test <- changePixelColor(img, coordinates, color = "blue")
-  expect_equal(test[1, 1, , ], as.vector(c(0, 0, 1)))
-  expect_equal(test[2, 2, , ], as.vector(c(1, 1, 1)))
-  expect_equal(test[1, 2, , ], as.vector(c(0, 0, 0)))
+  expect_equal(test[1, 1, ,], as.vector(c(0, 0, 1)))
+  expect_equal(test[2, 2, ,], as.vector(c(1, 1, 1)))
+  expect_equal(test[1, 2, ,], as.vector(c(0, 0, 0)))
 })
